# Release Notes

## Latest changes

## 1.1.0

Use uv & ruff as build infrastructure

Require Python 3.9+

## 1.0.6

Don't install a separate tests package, but include tests in source tarball

## 1.0.5

Rename BitcartCC to Bitcart

## 1.0.4

Re-generate protobuf files with the latest protoc

## 1.0.3

Support Python 3.11

## 1.0.2

Take deep copy of tx passed

## 1.0.1

Use older protobuf compiler for now

## 1.0.0

Initial release
